@@ -1,25 +1,32 @@
 """REST helpers for Muffin Framework."""
 
-__version__ = "4.0.0"
+__version__ = "4.1.1"
 __project__ = "muffin-rest"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
 
 # Default query params
-FILTERS_PARAM = 'where'
 LIMIT_PARAM = 'limit'
 OFFSET_PARAM = 'offset'
-SORT_PARAM = 'sort'
 
 
 from .api import API                # noqa
 from .handler import RESTHandler    # noqa
 from .errors import APIError        # noqa
 
+
 # Just an alias to support legacy style
 Api = API
 
 
+__all__ = (
+    'API', 'Api', 'RESTHandler', 'APIError',
+    'PWRESTHandler', 'PWFilter', 'PWFilters', 'PWSort', 'PWSorting',
+    'SARESTHandler', 'SAFilter', 'SAFilters', 'SASort', 'SASorting',
+    'MongoRESTHandler', 'MongoFilter', 'MongoFilters', 'MongoSort', 'MongoSorting',
+)
+
+
 # Support Peewee ORM
 try:
     from .peewee import PWRESTHandler
