@@ -6,10 +6,13 @@ import marshmallow as ma
 from muffin import Request
 from asgi_tools._compat import json_loads
 
-from . import FILTERS_PARAM, API
+from . import API
 from .utils import Mutate, Mutator, TCOLLECTION
 
 
+FILTERS_PARAM = 'where'
+
+
 class Filter(Mutate):
 
     """Base filter class."""
@@ -67,7 +70,7 @@ class Filter(Mutate):
 
         return ops, collection
 
-    async def filter(self, collection, *ops: t.Tuple[t.Callable, t.Any], **options):
+    async def filter(self, collection, *ops: t.Tuple[t.Callable, t.Any], **_):
         """Apply the filter to collection."""
         validator = lambda obj: all(op(get_value(obj, self.name), val) for (op, val) in ops)  # noqa
         return [o for o in collection if validator(o)]
@@ -92,6 +95,7 @@ class Filters(Mutator):
     """Build filters for handlers."""
 
     MUTATE_CLASS = Filter
+    mutations: t.Dict[str, Filter]  # type: ignore
 
     async def apply(self, request: Request, collection: TCOLLECTION, **options) -> TCOLLECTION:
         """Filter the given collection."""
