@@ -8,17 +8,15 @@ import marshmallow as ma
 import muffin
 import peewee as pw
 from apispec.ext.marshmallow import MarshmallowPlugin
-from marshmallow_peewee import ModelSchema, ForeignKey
-from peewee_aio import Manager, Model
+from marshmallow_peewee import ForeignKey, ModelSchema
 from muffin.typing import JSONType
+from peewee_aio import Manager, Model
 
-from ..handler import RESTBase, RESTOptions
-from ..errors import APIError
-
-from .openapi import PeeweeOpenAPIMixin
-from .filters import PWFilters
-from .sorting import PWSorting
-
+from muffin_rest.errors import APIError
+from muffin_rest.handler import RESTBase, RESTOptions
+from muffin_rest.peewee.filters import PWFilters
+from muffin_rest.peewee.openapi import PeeweeOpenAPIMixin
+from muffin_rest.peewee.sorting import PWSorting
 
 # XXX: Patch apispec.MarshmallowPlugin to support ForeignKeyField
 MarshmallowPlugin.Converter.field_mapping[ForeignKey] = ("integer", None)
@@ -27,7 +25,7 @@ MarshmallowPlugin.Converter.field_mapping[ForeignKey] = ("integer", None)
 class PWRESTOptions(RESTOptions):
     """Support Peewee."""
 
-    model: pw.Model
+    model: t.Type[pw.Model]
     model_pk: t.Optional[pw.Field] = None
 
     manager: Manager
@@ -43,22 +41,33 @@ class PWRESTOptions(RESTOptions):
     # Schema auto generation params
     schema_base: t.Type[ModelSchema] = ModelSchema
 
-    base_property: str = 'model'
+    # Recursive delete
+    delete_recursive = False
+
+    base_property: str = "model"
 
     def setup(self, cls):
         """Prepare meta options."""
         self.name = self.name or self.model._meta.table_name.lower()
         self.model_pk = self.model_pk or self.model._meta.primary_key
-        self.manager = getattr(self, 'manager', getattr(self.model._meta, 'manager', None))
-        if self.manager is None:
-            raise RuntimeError('Peewee-AIO ORM Manager is not available')
+        manager = getattr(self, "manager", getattr(self.model, "_manager", None))
+        if manager is None:
+            raise RuntimeError("Peewee-AIO ORM Manager is not available")
 
-        super(PWRESTOptions, self).setup(cls)
+        self.manager = manager
 
-    def setup_schema_meta(self, cls):
+        super().setup(cls)
+
+    def setup_schema_meta(self, _):
         """Prepare a schema."""
-        return type('Meta', (object,), dict(
-            {'unknown': self.schema_unknown, 'model': self.model}, **self.schema_meta))
+        return type(
+            "Meta",
+            (object,),
+            dict(
+                {"unknown": self.schema_unknown, "model": self.model},
+                **self.schema_meta,
+            ),
+        )
 
 
 class PWRESTBase(RESTBase):
@@ -69,53 +78,50 @@ class PWRESTBase(RESTBase):
     meta: PWRESTOptions
     meta_class: t.Type[PWRESTOptions] = PWRESTOptions
 
-    async def prepare_collection(self, request: muffin.Request) -> pw.Query:
+    async def prepare_collection(self, _: muffin.Request) -> pw.Query:
         """Initialize Peeewee QuerySet for a binded to the resource model."""
         return self.meta.model.select()
 
     async def prepare_resource(self, request: muffin.Request) -> t.Optional[pw.Model]:
         """Load a resource."""
-        pk = request['path_params'].get(self.meta.name_id)
+        pk = request["path_params"].get(self.meta.name_id)
         if not pk:
             return None
 
         meta = self.meta
 
-        resource = await meta.manager.fetchone(self.collection.where(meta.model_pk == pk))
+        resource = await meta.manager.fetchone(
+            self.collection.where(meta.model_pk == pk)
+        )
         if resource is None:
-            raise APIError.NOT_FOUND('Resource not found')
+            raise APIError.NOT_FOUND("Resource not found")
         return resource
 
-    async def paginate(self, request: muffin.Request, *, limit: int = 0,
-                       offset: int = 0) -> t.Tuple[pw.Query, int]:
+    async def paginate(
+        self, _: muffin.Request, *, limit: int = 0, offset: int = 0
+    ) -> t.Tuple[pw.Query, int]:
         """Paginate the collection."""
-        cqs = self.collection.order_by()
+        cqs: pw.Select = self.collection.order_by()  # type: ignore
         if cqs._group_by:
-            cqs._select = cqs._group_by
+            cqs._returning = cqs._group_by
         count = await self.meta.manager.count(cqs)
-        return self.collection.offset(offset).limit(limit), count
+        return self.collection.offset(offset).limit(limit), count  # type: ignore
 
     async def get(self, request, *, resource=None) -> JSONType:
         """Get resource or collection of resources."""
-        if resource is not None and resource != '':
+        if resource is not None and resource != "":
             return await self.dump(request, resource, many=False)
 
         resources = await self.meta.manager.fetchall(self.collection)
         return await self.dump(request, resources, many=True)
 
-    async def save(self, request: muffin.Request,  # type: ignore
-                   resource: t.Union[pw.Model, t.List[pw.Model]]):
-        """Save the given resource.
-
-        Supports batch saving.
-        """
+    async def save(self, _: muffin.Request, resource: pw.Model) -> pw.Model:
+        """Save the given resource."""
         meta = self.meta
-        save = meta.manager.save
         if issubclass(meta.model, Model):
-            save = lambda m: m.save()  # type: ignore  # noqa
-
-        for obj in (resource if isinstance(resource, list) else [resource]):
-            await save(obj)
+            await resource.save()
+        else:
+            await meta.manager.save(resource)
 
         return resource
 
@@ -131,26 +137,30 @@ class PWRESTBase(RESTBase):
                 return
 
             model_pk = t.cast(pw.Field, meta.model_pk)
-            resources = await meta.manager.fetchall(self.collection.where(model_pk << data))
+            resources = await meta.manager.fetchall(
+                self.collection.where(model_pk << data)
+            )
 
         if not resources:
             raise APIError.NOT_FOUND()
 
         delete_instance = meta.manager.delete_instance
         if issubclass(meta.model, Model):
-            delete_instance = lambda m: m.delete_instance()  # type: ignore  # noqa
+            delete_instance = lambda m: m.delete_instance(recursive=meta.delete_recursive)  # type: ignore  # noqa
 
-        for resource in resources:
-            await delete_instance(resource)
+        for res in resources:
+            await delete_instance(res)
 
     delete = remove  # noqa
 
-    async def get_schema(self, request: muffin.Request, resource=None) -> ma.Schema:
+    async def get_schema(
+        self, request: muffin.Request, resource=None, **_
+    ) -> ma.Schema:
         """Initialize marshmallow schema for serialization/deserialization."""
         return self.meta.Schema(
             instance=resource,
-            only=request.url.query.get('schema_only'),
-            exclude=request.url.query.get('schema_exclude', ()),
+            only=request.url.query.get("schema_only"),
+            exclude=request.url.query.get("schema_exclude", ()),
         )
 
 
